Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(966)

Unified Diff: components/content_settings/core/browser/website_settings_info.h

Issue 2075103002: Change ContentSettingsType's scoping type and hookup migration code (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@do_migration_after_sync
Patch Set: revise test Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/content_settings/core/browser/website_settings_info.h
diff --git a/components/content_settings/core/browser/website_settings_info.h b/components/content_settings/core/browser/website_settings_info.h
index 762e32e828c4e52f58a802817d527fdb920a9297..049a31beb65ef14244794624421fd66cf89342b8 100644
--- a/components/content_settings/core/browser/website_settings_info.h
+++ b/components/content_settings/core/browser/website_settings_info.h
@@ -27,12 +27,8 @@ class WebsiteSettingsInfo {
enum LossyStatus { LOSSY, NOT_LOSSY };
enum ScopingType {
- // Settings scoped to the domain of the main frame only.
- TOP_LEVEL_DOMAIN_ONLY_SCOPE,
-
- // Settings scoped to the domain of the requesting frame only. This should
- // not generally be used.
- REQUESTING_DOMAIN_ONLY_SCOPE,
+ // Settings scoped to the origin of the main frame only.
+ TOP_LEVEL_ORIGIN_ONLY_SCOPE,
// Settings scoped to the origin of the requesting frame only.
REQUESTING_ORIGIN_ONLY_SCOPE,

Powered by Google App Engine
This is Rietveld 408576698